ToastWidget class
A widget representing a toast notification.
The message, duration, position, backgroundColor, textStyle, borderRadius, and icon parameters allow for complete customization of the toast appearance and behavior. The onTap parameter provides an optional callback when the toast is tapped.
Example usage:
ToastWidget(
message: "Event created successfully",
description: "Sunday, December 03, 2023 at 9:00 AM",
duration: Duration(seconds: 3),
position: ToastPosition.bottom,
backgroundColor: Colors.green,
textStyle: TextStyle(color: Colors.white),
borderRadius: BorderRadius.all(Radius.circular(8)),
icon: Icon(Icons.check_circle, color: Colors.white),
onTap: () { print("Toast tapped!"); },
);
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- ToastWidget
Constructors
- ToastWidget({Key? key, required String message, String? description, required Duration duration, required ToastPosition position, required Color backgroundColor, required TextStyle textStyle, required BorderRadiusGeometry borderRadius, Widget? icon, VoidCallback? onTap, String? actionLabel, VoidCallback? onActionPressed})
-
const
Properties
- actionLabel → String?
-
final
- backgroundColor → Color
-
final
- borderRadius → BorderRadiusGeometry
-
final
- description → String?
-
final
- duration → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- message → String
-
final
- onActionPressed → VoidCallback?
-
final
- onTap → VoidCallback?
-
final
- position → ToastPosition
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textStyle → TextStyle
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited